@@ -31,7 +31,14 @@
 #
 #
 plot.SosObservationOffering <- function(x, y, ..., add = FALSE) {
-	.off.spatial <- as(x, "Spatial")
+	.off.spatial <- NULL
+	tryCatch({.off.spatial <- as(x, "Spatial") },
+			error = function(e) { 
+				warning(paste("Cannot not coerce offering", toString(sosId(x)),
+								"to Spatial for plotting -- Error: ", e))
+				
+				return()
+			})
 	
 	if(is.null(.off.spatial))
 		warning("Cannot plot NULL offering!")
