@@ -33,46 +33,46 @@ library("RCurl")
 library("sp")
 
 # load required source files for testing
-if(!exists(".path"))
-	.path = "/home/daniel/Dokumente/2010_SOS4R/workspace/sos4R"
+if(!exists(".sos4Rpath"))
+	.sos4Rpath = "/home/daniel/Dokumente/2010_SOS4R/workspace/sos4R"
+	
+source(paste(.sos4Rpath, "R", "Constants.R",  sep = "/"))
 
-source(paste(.path, "R", "Constants.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Class-OWS.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Class-GML.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Class-SWE.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Class-OM.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Class-SA.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Class-OGC.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Class-SOS.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Class-SML.R",  sep = "/"))
 
-source(paste(.path, "R", "Class-OWS.R",  sep = "/"))
-source(paste(.path, "R", "Class-GML.R",  sep = "/"))
-source(paste(.path, "R", "Class-SWE.R",  sep = "/"))
-source(paste(.path, "R", "Class-OM.R",  sep = "/"))
-source(paste(.path, "R", "Class-SA.R",  sep = "/"))
-source(paste(.path, "R", "Class-OGC.R",  sep = "/"))
-source(paste(.path, "R", "Class-SOS.R",  sep = "/"))
-source(paste(.path, "R", "Class-SML.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Generic-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "OWS-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "OWS-methods-parsing.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SOS-methods-parsing.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SOS-methods-plotting.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "OM-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "OM-methods-parsing.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "OM-methods-coercion.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SA-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "GML-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SWE-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "GML-methods-parsing.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SA-methods-parsing.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SWE-methods-parsing.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "OGC-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SML-methods.R",  sep = "/"))
 
-source(paste(.path, "R", "Generic-methods.R",  sep = "/"))
-source(paste(.path, "R", "OWS-methods.R",  sep = "/"))
-source(paste(.path, "R", "OWS-methods-parsing.R",  sep = "/"))
-source(paste(.path, "R", "SOS-methods-parsing.R",  sep = "/"))
-source(paste(.path, "R", "SOS-methods-plotting.R",  sep = "/"))
-source(paste(.path, "R", "OM-methods.R",  sep = "/"))
-source(paste(.path, "R", "OM-methods-parsing.R",  sep = "/"))
-source(paste(.path, "R", "OM-methods-coercion.R",  sep = "/"))
-source(paste(.path, "R", "SA-methods.R",  sep = "/"))
-source(paste(.path, "R", "GML-methods.R",  sep = "/"))
-source(paste(.path, "R", "SWE-methods.R",  sep = "/"))
-source(paste(.path, "R", "GML-methods-parsing.R",  sep = "/"))
-source(paste(.path, "R", "SA-methods-parsing.R",  sep = "/"))
-source(paste(.path, "R", "SWE-methods-parsing.R",  sep = "/"))
-source(paste(.path, "R", "OGC-methods.R",  sep = "/"))
-source(paste(.path, "R", "SML-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "PrintShowStructureSummmary-methods.R",  sep = "/"))
 
-source(paste(.path, "R", "PrintShowStructureSummmary-methods.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SOS-methods-coercion.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SML-methods-coercion.R",  sep = "/"))
 
-source(paste(.path, "R", "SOS-methods-coercion.R",  sep = "/"))
-source(paste(.path, "R", "SML-methods-coercion.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SOS-methods-accessor.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SOS-methods-util.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SML-methods-util.R",  sep = "/"))
 
-source(paste(.path, "R", "SOS-methods-accessor.R",  sep = "/"))
-source(paste(.path, "R", "SOS-methods-util.R",  sep = "/"))
-source(paste(.path, "R", "SML-methods-util.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "SOS-methods.R",  sep = "/"))
 
-source(paste(.path, "R", "SOS-methods.R",  sep = "/"))
-
-source(paste(.path, "R", "Defaults.R",  sep = "/"))
+source(paste(.sos4Rpath, "R", "Defaults.R",  sep = "/"))
